diff -u dnsmasq-2.70/debian/changelog dnsmasq-2.70/debian/changelog
--- dnsmasq-2.70/debian/changelog
+++ dnsmasq-2.70/debian/changelog
@@ -1,3 +1,14 @@
+dnsmasq (2.70-2.1) UNRELEASED; urgency=medium
+
+  * Non-maintainer upload.
+  * Enable dnsmasq systemd unit on install. Otherwise dnsmasq does not run on
+    fresh installations (without administrator handholding) and even worse it
+    is disabled on systems switching from sysv to systemd. Modify
+    postinst/postrm exactly as dh_systemd would, add dependency on
+    init-system-helpers. Closes: #724602
+
+ -- Andreas Metzler <ametzler@debian.org>  Sun, 11 May 2014 15:27:50 +0200
+
 dnsmasq (2.70-2) unstable; urgency=low
 
    * Ensure daemon not stared if dnsmasq package has been removed,
diff -u dnsmasq-2.70/debian/control dnsmasq-2.70/debian/control
--- dnsmasq-2.70/debian/control
+++ dnsmasq-2.70/debian/control
@@ -8,7 +8,8 @@
 
 Package: dnsmasq
 Architecture: all
-Depends: netbase, dnsmasq-base(>= ${binary:Version})
+Depends: netbase, dnsmasq-base(>= ${binary:Version}), 
+         init-system-helpers (>= 1.18~)
 Suggests: resolvconf
 Conflicts: resolvconf (<<1.15)
 Description: Small caching DNS proxy and DHCP/TFTP server
diff -u dnsmasq-2.70/debian/postinst dnsmasq-2.70/debian/postinst
--- dnsmasq-2.70/debian/postinst
+++ dnsmasq-2.70/debian/postinst
@@ -1,6 +1,22 @@
 #!/bin/sh
 set -e
 
+# Code copied from dh_systemd_enable ----------------------
+# This will only remove masks created by d-s-h on package removal.
+deb-systemd-helper unmask dnsmasq.service >/dev/null || true
+
+# was-enabled defaults to true, so new installations run enable.
+if deb-systemd-helper --quiet was-enabled dnsmasq.service; then
+	# Enables the unit on first installation, creates new
+	# symlinks on upgrades if the unit file has changed.
+	deb-systemd-helper enable dnsmasq.service >/dev/null || true
+else
+	# Update the statefile to add new symlinks (if any), which need to be
+	# cleaned up on purge. Also remove old symlinks.
+	deb-systemd-helper update-state dnsmasq.service >/dev/null || true
+fi
+# End code copied from dh_systemd_enable ------------------
+
 if [ -x /etc/init.d/dnsmasq ]; then
    update-rc.d dnsmasq defaults 15 85 >/dev/null
 
diff -u dnsmasq-2.70/debian/postrm dnsmasq-2.70/debian/postrm
--- dnsmasq-2.70/debian/postrm
+++ dnsmasq-2.70/debian/postrm
@@ -6,0 +7,15 @@
+
+# Code copied from dh_systemd_enable ----------------------
+if [ "$1" = "remove" ]; then
+	if [ -x "/usr/bin/deb-systemd-helper" ]; then
+		deb-systemd-helper mask dnsmasq.service >/dev/null
+	fi
+fi
+
+if [ "$1" = "purge" ]; then
+	if [ -x "/usr/bin/deb-systemd-helper" ]; then
+		deb-systemd-helper purge dnsmasq.service >/dev/null
+		deb-systemd-helper unmask dnsmasq.service >/dev/null
+	fi
+fi
+# End code copied from dh_systemd_enable ------------------
